@@ -12,7 +12,7 @@ sub mailer {
   return @{ $self->{mailer} || \@MAILER };
 }
 
-sub send {
+sub run {
   my $self = shift;
 
   my $body = $self->trap_send(@_);
@@ -21,6 +21,8 @@ sub send {
   $mailer->close;
 }
 
+*send = \&run;
+
 =head1 NAME
 
 Text::Forge::Mail - e-mail templating system
